=======
History
=======
0.3.x (2024-10-02)
------------------
* Add an option to repeat events forever
* Calculate prev/next occurrences more efficiently
* Make the calendar entry name mandatory

0.3.0 (2024-10-02)
------------------
* Breaking change: Total refactoring of models to better align with ical/dateutil rrules.

0.2.0 (2024-10-01)
------------------
* Allow downloading ical strings from the admin

0.1.0 (2024-09-28)
------------------

* First release on PyPI.
